#####################
Temptronic Base Class
#####################

.. autoclass:: pymeasure.instruments.temptronic.ATSBase
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.temptronic.temptronic_base.TemperatureStatusCode
.. autoclass:: pymeasure.instruments.temptronic.temptronic_base.ErrorCode
